# XT-STREAMLIT - 1.1.5

This repo contains all of the common Streamlit code used by the Exploration Toolkit and CMR's Discovery Program.

## `xt-st-common` - Common Framework for XT's Streamlit apps

## Getting Started User
TODO: Installation guide and pointer to API docs

## Getting Started Developer
TODO: Poetry primer

This project recommends using [poethepoet](https://poethepoet.natn.io/index.html) as a tool for running tasks. See `pypoetry.toml`

In your base python environment
``` bash
pip install pipx # Pipx is a tool for installing python tools globally
pipx install poethepoet # Installs poe as a global tool
poe --help # Will show all the available tasks defined for this project
```
